source("http://ashipunov.info/shipunov/school/biol_240/ncov.r", echo=TRUE)
plot(log(confirmed) ~ dt, data=cc, type="b", xlab="Date", ylab="Confirmed cases (log)")

## source("http://ashipunov.info/shipunov/school/biol_240/scriptb.r", echo=TRUE) # error!
## t1 <- read.table("trees_m.txt") # this the place of error
## file.show("trees_m.txt") # look on data
## str(t1) # look on result (1)
## head(t1) # look on result (2)
## url.show("http://ashipunov.info/shipunov/school/biol_240/scriptb.r") # look on script
## this is how to do it properly:
trees.m <- data.frame(trees[1]*2.54, trees[2]*30.48, trees[3]*(30.38^3))
write.table(trees.m, file="trees_m.txt", row.names=FALSE, quote=FALSE)
t2 <- read.table("trees_m.txt", h=TRUE)
t2.scaled <- scale(t2)
boxplot(t2.scaled)
## unlink("trees_m.txt") # do not forget to remove the file (but be careful with this command!)

iris.p <- prcomp(iris[, -5], scale=TRUE)
iris.p # loadings (importances of variables)
summary(iris.p) # total variance explained (importances of components)
biplot(iris.p, xpd=TRUE) # shows both original and PCA variables
iris[16, ] # row number 16

library(shipunov)
plot(iris.p$x, col=iris$Species)
iris.h <- Hulls(iris.p$x[, 1:2], groups=iris$Species)
summary(Overlap(iris.h))

mh <- read.table("http://ashipunov.info/shipunov/school/biol_240/sample_murina_hilgendorfi.txt", h=TRUE, sep="\t")
str(mh)
Str(mh) # useful command: shows number of variable and presence of missing data
sapply(mh[, -(1:4)], Normality) # some variab;es are not normal
mh.cor <- cor(mh[, -(1:4)], method="spearman") # correlation matrix, non-parametric
Pleiad(mh.cor, corr=TRUE, breaks=3) # correlogramm

mh.p <- prcomp(mh[, -(1:4)], scale=TRUE)
palette(rainbow(nlevels(mh$locality)))
plot(mh.p$x, col=mh$locality, pch=as.character(mh$locality))
mh.ph <- Hulls(mh.p$x, groups=mh$locality)
summary(Overlap(mh.ph)) # calculates overlap of each with all others
palette("default")
Biarrows(mh.p$x, scale(mh[, -(1:4)]), ar.col=1, tx.col=1) # biplot-like

iris.d <- dist(iris[, -5], method="euclidean")
iris.g <- Gower.dist(iris)

iris.c1 <- cmdscale(iris.d)
plot(iris.c1, col=iris$Species)
Hulls(iris.c1, groups=iris$Species)
MDSv(iris.c1) # importances of dimentions (surrogate explained variance)
Biarrows(iris.c1, scale(iris[, -5])) # biplot-like but for MDS

iris.c2 <- cmdscale(iris.g)
plot(iris.c2, col=iris$Species)
Hulls(iris.c2, groups=iris$Species) # much better -- because we told species

library(vegan)
anosim(iris.c1, iris$Species, dist="euclidean")
anosim(iris.c2, iris$Species, dist="euclidean")
anosim(iris.p$x[, 1:2], iris$Species, dist="euclidean")

iris.10 <- iris[c(rep(0, 9), 1) > 0, ] # every 10th row
c(rep(0, 9), 1) > 0 # this is simply 9 FALSE and 1 TRUE
iris.10d <- dist(iris.10[, -5])
iris.10dh <- hclust(iris.10d, method="ward.D") # Ward method makes sharp clusters
plot(iris.10dh, labels=iris.10$Species)

iris.10b <- Bclust(iris.10[, -5])
plot(iris.10b$hclust, labels=iris.10$Species)
Bclabels(iris.10b$hclust, iris.10b$values, col="red", pos=3, offset=0.1)

iris.k <- kmeans(iris[, -5], centers=3)
plot(iris.p$x, col=iris$Species, pch=iris.k$cluster)
Misclass(iris.k$cluster, iris$Species, best=TRUE)

library(meanShiftR)
iris.m <- meanShift(as.matrix(iris[, -5]))
plot(iris.p$x, col=iris$Species, pch=iris.m$assignment)
Misclass(iris.m$assignment, iris$Species, best=TRUE)

mh.m <- meanShift(as.matrix(mh[, -(1:4)]))
palette(rainbow(nlevels(mh$locality)))
plot(mh.p$x, col=mh$locality, pch=mh.m$assignment) # not useful...

mh.k <- kmeans(mh[, -(1:4)], centers=5)
plot(mh.p$x, col=mh$locality, pch=mh.k$cluster)
## Misclass(mh$locality, mh.k$cluster, best=TRUE) # Misclass() does not work well with 9 classes
new <- as.character(mh$locality) # colnvert locality to character
new2 <- ifelse(!new %in% c("W", "I", "L", "U"), "C", new) # 5 classes only
Misclass(new2, mh.k$cluster, best=TRUE) # insteresting!

library(vegan)
mh.d <- dist(mh[, -(1:4)])
mh.mds <- metaMDS(mh.d, distance="euclidean") # run several times, not always converged
plot(mh.mds$points, col=mh$locality, pch=as.character(mh$locality))
mh.h2 <- Hulls(mh.mds$points, groups=mh$locality)
summary(Overlap(mh.h2))
palette("default")
Biarrows(mh.mds$points, mh[, -c(1:4)], ar.col=1, tx.col=1, lty=2)
